#
# spec file for package reprepro
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           reprepro
Version:        5.4.1
Release:        bp156.2.7
Summary:        Debian repository metadata generator
License:        GPL-2.0-only AND GPL-2.0-or-later AND MIT
URL:            https://salsa.debian.org/debian/reprepro
Source:         http://deb.debian.org/debian/pool/main/r/reprepro/reprepro_%version.orig.tar.xz
BuildRequires:  automake
BuildRequires:  gpgme-devel
BuildRequires:  libarchive-devel
BuildRequires:  libzstd-devel
BuildRequires:  xz-devel
BuildRequires:  zlib-devel
%if 0%{?suse_version}
BuildRequires:  libbz2-devel
BuildRequires:  libdb-4_8-devel
Requires:       gpg2
%else
BuildRequires:  bzip2-devel
BuildRequires:  (db4-devel or libdb-devel)
Requires:       gnupg2
%endif
Requires:       bzip2
Requires:       tar
Requires:       zstd

%description
reprepro is a tool to manage a repository of Debian packages (.deb).  It
stores files either being injected manually or downloaded from some other
repository (partially) mirrored into one pool/ hierarchy.  Managed packages
and files are stored in a Berkeley DB, so no database server is needed.
Checking signatures of mirrored repositories and creating signatures of the
generated Package indexes is supported.

%prep
%autosetup -p1
find docs -type f -exec chmod -x {} +

%build
export CFLAGS="%optflags -g"
autoreconf -fi
%configure
%make_build

%install
%make_install
pushd docs
rm -v Makefile Makefile.am Makefile.in changestool.1 rredtool.1 reprepro.1

%files
%license COPYING
%doc docs/ AUTHORS README NEWS
%_mandir/man1/*.1*
%_bindir/changestool
%_bindir/reprepro
%_bindir/rredtool

%changelog
* Thu Nov 17 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 5.4.1
  * If data tar extraction fails, try again as uncompressed.
* Tue Aug 16 2022 Michael Calmer <mc@suse.com>
- Update to version 5.4.0
  * Updates between 5.3.1 and 5.4.0:
    + Add shunit2 based tests (https://bugs.debian.org/857302)
    + Support multiple versions. (https://bugs.debian.org/570623)
    + Add the commands move, movesrc, movematched, movefilter
    + Add Limit and Archive option
  * Updates between 5.3.0 and 5.3.1:
    + fix manpage to add the behaviour if reprepro is linked against liblzma
    + mark 'dumpcontents' command as deprecated
    + Add Zstd support
- Removed patches (upstream)
  * 0001-add-zstd-support.patch
  * 0002-Flush-stdout-stderr-before-calling-endhook.patch
  * 0001-Bump-up-the-maxsize-on-a-fixed-size-C-buffer-to-avoi.patch
- Removed GPG signature (not provided anymore)
  * reprepro_5.3.0.orig.tar.gz.asc
  * reprepro.keyring
* Tue Aug 16 2022 Michael Calmer <mc@suse.com>
- Add missing changelogs
  * Bump up the maxsize on a fixed-size C buffer to avoid breaking on some
    autogenerated rust packages
  * 0001-Bump-up-the-maxsize-on-a-fixed-size-C-buffer-to-avoi.patch
  * Flush stdout and stderr before execv of an end hook
  * 0002-Flush-stdout-stderr-before-calling-endhook.patch
  * Added GPG signature
* Tue Apr 19 2022 Michael Ströder <michael@stroeder.com>
- added 0001-add-zstd-support.patch
* Wed Dec  1 2021 Jan Engelhardt <jengelh@inai.de>
- Initial package (version 5.3.0) for build.opensuse.org
